@@ -47,7 +47,7 @@ __all__ = [
 
 Actor_co = TypeVar("Actor_co", bound="clu.base.BaseActor")
 Future_co = TypeVar("Future_co", bound="BaseCommand")
-
+Reply_co = TypeVar("Reply_co", bound="clu.base.Reply")
 
 if sys.version_info >= (3, 9, 0):
     Future = asyncio.Future
@@ -57,6 +57,19 @@ else:
         pass
 
 
+class ReplyList(List[Reply_co]):
+    """A list of replies to a command."""
+
+    def get(self, keyword: str):
+        """Return the value of the reply that matches the key."""
+
+        for reply in self:
+            if keyword in reply.message:
+                return reply.message[keyword]
+
+        raise KeyError(f"Keyword {keyword} not found.")
+
+
 class BaseCommand(
     Future[Future_co],
     StatusMixIn[CommandStatus],
@@ -140,7 +153,7 @@ class BaseCommand(
 
         #: A list of replies this command has received. The type of
         #: reply object depends on the actor or client issuing the command.
-        self.replies: List[Any] = []
+        self.replies = ReplyList([])
 
         asyncio.Future.__init__(self)
 
@@ -237,7 +250,7 @@ class BaseCommand(
 
             # If the command is done, set the result of the future.
             if self._status.is_done and not self.done():
-                self.set_result(self)
+                self.set_result(self)  # type: ignore
                 if self._timer_handler:
                     self._timer_handler.cancel()
 
@@ -342,7 +355,7 @@ class BaseCommand(
         command_string: str,
         *args,
         **kwargs,
-    ) -> BaseCommand | Awaitable[Command]:
+    ) -> BaseCommand[Actor_co, BaseCommand] | Awaitable[BaseCommand]:
         """Sends a command to an actor using the commander ID of this command."""
 
         if self.actor is None:
