@@ -17,7 +17,7 @@ from threading import Lock
 
 from typing import Any, Callable, List, Optional
 
-from clu.base import BaseClient
+import clu.base
 from clu.command import Command, CommandStatus
 from clu.exceptions import CluWarning
 from clu.model import BaseModel, Property
@@ -112,6 +112,8 @@ class TronModel(BaseModel[TronKey]):
     def parse_reply(self, reply):
         """Parses a reply and updates the datamodel."""
 
+        parsed: dict[str, Any] = {}
+
         with self._lock:
             for reply_key in reply.keywords:
 
@@ -134,12 +136,15 @@ class TronModel(BaseModel[TronKey]):
                         f"Failed parsing keyword {self.name}.{reply_key.name}.",
                         CluWarning,
                     )
-                    return
+                    continue
 
                 self[key_name].update_keyword(reply_key)
+                parsed[key_name] = self[key_name].value.copy()
 
                 self.notify(self.flatten(), self[key_name].copy())
 
+        return parsed
+
 
 class TronLoggingFilter(logging.Filter):
     """Logs issues with the Tron parser only to the file logger."""
@@ -159,7 +164,7 @@ class TronClientProtocol(ReconnectingTCPClientProtocol):
         self._loop.call_soon(self._on_received, data)
 
 
-class TronConnection(BaseClient):
+class TronConnection(clu.base.BaseClient):
     """Allows to send commands to Tron and manages the feed of replies.
 
     Parameters
@@ -315,8 +320,8 @@ class TronConnection(BaseClient):
         mid = mid or self._mid
 
         # The mid must be a 32-bit unsigned number.
-        if mid >= 2 ** 32:
-            self._mid = mid = mid % 2 ** 32
+        if mid >= 2**32:
+            self._mid = mid = mid % 2**32
 
         if len(args) > 0:
             command_string += " " + " ".join(map(str, args))
@@ -377,7 +382,7 @@ class TronConnection(BaseClient):
             try:
                 # Do not strip here or that will cause parsing problems.
                 line = line.decode()
-                reply = self.rparser.parse(line)
+                reply: Reply = self.rparser.parse(line)
             except ParseError:
                 self.log.warning(f"Failed parsing reply '{line.strip()}'.")
                 continue
@@ -389,19 +394,32 @@ class TronConnection(BaseClient):
             if actor.startswith("keys_"):
                 actor = actor.split("_")[1]
 
+            parsed_data = {}
             if actor in self.models:
                 try:
-                    self.models[actor].parse_reply(reply)
+                    parsed_data = self.models[actor].parse_reply(reply)
                 except ParseError as ee:
                     self.log.warning(
                         f"Failed parsing reply {reply!r} with error: {ee!s}"
                     )
+            else:
+                # Fallback in case the actor of the reply is not in the models.
+                # In this case the values will be strings.
+                parsed_data = {kw.name: kw.values for kw in reply.keywords}
 
             mid = reply.header.commandId
             status = CommandStatus.code_to_status(reply.header.code.lower())
 
             if mid in self.running_commands:
-                self.running_commands[mid].replies.append(reply)
+                self.running_commands[mid].replies.append(
+                    clu.base.Reply(
+                        message={k: v for k, v in parsed_data.items()},
+                        message_code=reply.header.code.lower(),
+                        command=self.running_commands[mid],
+                        validated=True,
+                        keywords=reply.keywords,
+                    )
+                )
                 self.running_commands[mid].set_status(status)
                 if self.running_commands[mid]._reply_callback is not None:
                     self.running_commands[mid]._reply_callback(reply)
